@@ -28,7 +28,7 @@
 #include "prefs/koprefs.h"
 
 #include <CalendarSupport/CategoryConfig>
-#include <Libkdepim/TagWidgets>
+#include <LibkdepimAkonadi/TagWidgets>
 #include <PimCommon/PimUtil>
 
 #include <KCalCore/CalFilter>
@@ -46,8 +46,9 @@ FilterEditDialog::FilterEditDialog(QList<KCalCore::CalFilter *> *filters, QWidge
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title::window", "Edit Calendar Filters"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mApplyButton = buttonBox->button(QDialogButtonBox::Apply);
     mOkButton->setDefault(true);
@@ -67,7 +68,7 @@ FilterEditDialog::FilterEditDialog(QList<KCalCore::CalFilter *> *filters, QWidge
 FilterEditDialog::~FilterEditDialog()
 {
     delete mFilterEdit;
-    mFilterEdit = Q_NULLPTR;
+    mFilterEdit = nullptr;
 }
 
 void FilterEditDialog::updateFilterList()
@@ -93,7 +94,7 @@ void FilterEditDialog::setDialogConsistent(bool consistent)
 }
 
 FilterEdit::FilterEdit(QList<KCalCore::CalFilter *> *filters, QWidget *parent)
-    : QWidget(parent), mCurrent(Q_NULLPTR), mCategorySelectDialog(Q_NULLPTR)
+    : QWidget(parent), mCurrent(nullptr), mCategorySelectDialog(nullptr)
 {
     setupUi(this);
     searchline->setListWidget(mRulesList);
@@ -130,7 +131,8 @@ void FilterEdit::updateFilterList()
         Q_EMIT(dataConsistent(false));
     } else {
         QList<KCalCore::CalFilter *>::iterator i;
-        for (i = mFilters->begin(); i != mFilters->end(); ++i) {
+        QList<KCalCore::CalFilter *>::iterator end(mFilters->end());
+        for (i = mFilters->begin(); i != end; ++i) {
             if (*i) {
                 mRulesList->addItem((*i)->name());
             }
@@ -143,7 +145,7 @@ void FilterEdit::updateFilterList()
         }
         Q_EMIT(dataConsistent(true));
     }
-    if (mFilters && mFilters->count() > 0 && !mCurrent) {
+    if (mFilters && !mFilters->isEmpty() && !mCurrent) {
         filterSelected(mFilters->at(0));
     }
     if (mFilters) {
@@ -178,7 +180,8 @@ void FilterEdit::saveChanges()
     mCurrent->setCompletedTimeSpan(mCompletedTimeSpan->value());
 
     QStringList categoryList;
-    for (int i = 0; i < mCatList->count(); ++i) {
+    const int numberOfCat(mCatList->count());
+    for (int i = 0; i < numberOfCat; ++i) {
         QListWidgetItem *item = mCatList->item(i);
         if (item) {
             categoryList.append(item->text());
@@ -275,7 +278,7 @@ void FilterEdit::bDeletePressed()
     KCalCore::CalFilter *filter = mFilters->at(selected);
     mFilters->removeAll(filter);
     delete filter;
-    mCurrent = Q_NULLPTR;
+    mCurrent = nullptr;
     updateFilterList();
     mRulesList->setCurrentRow(qMin(mRulesList->count() - 1, selected));
     Q_EMIT filterChanged();
@@ -306,13 +309,13 @@ void FilterEdit::updateSelectedName(const QString &newText)
 
 bool FilterEdit::correctName(const QString &newText)
 {
+    bool negative = false;
 #ifndef QT_NO_STYLE_STYLESHEET
     QString styleSheet;
     if (mNegativeBackground.isEmpty()) {
         KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
         mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mNameLineEdit).color().name());
     }
-    bool negative = false;
     if (!newText.isEmpty()) {
         for (int i = 0; i < mRulesList->count(); ++i) {
             QListWidgetItem *item = mRulesList->item(i);
