@@ -93,7 +93,7 @@ void HtmlExportJob::start()
     bool canExportItem = false;
     // first collect the email addresses of all organisators
     const KCalCore::Event::List events = d->mCalendar->events();
-    foreach (const KCalCore::Event::Ptr &event, events) {
+    for (const KCalCore::Event::Ptr &event : events) {
         Q_ASSERT(event);
         const KCalCore::Attendee::List attendees = event->attendees();
         if (!attendees.isEmpty()) {
@@ -109,7 +109,7 @@ void HtmlExportJob::start()
     }
 
     const KCalCore::Todo::List todos = d->mCalendar->todos();
-    foreach (const KCalCore::Todo::Ptr &todo, todos) {
+    for (const KCalCore::Todo::Ptr &todo : todos) {
         Q_ASSERT(todo);
         const KCalCore::Attendee::List attendees = todo->attendees();
         if (!attendees.isEmpty()) {
@@ -361,7 +361,7 @@ void HtmlExportJob::createMonthView(QTextStream *ts)
                     KCalCore::Event::List events = d->mCalendar->events(start, d->mCalendar->timeSpec(),
                                                    KCalCore::EventSortStartDate,
                                                    KCalCore::SortDirectionAscending);
-                    if (events.count()) {
+                    if (!events.isEmpty()) {
                         *ts << "<table>";
                         foreach (const KCalCore::Event::Ptr &event, events) {
                             Q_ASSERT(event);
@@ -506,7 +506,7 @@ void HtmlExportJob::createTodoList(QTextStream *ts)
     while (index < rawTodoList.count()) {
         const KCalCore::Todo::Ptr todo = rawTodoList.value(index);
         Q_ASSERT(todo);
-        const Akonadi::Item parentItem = d->mCalendar->item(todo->relatedTo());
+        //const Akonadi::Item parentItem = d->mCalendar->item(todo->relatedTo());
 
         ++index;
     }
@@ -632,7 +632,7 @@ void HtmlExportJob::createTodo(QTextStream *ts, const KCalCore::Todo::Ptr &todo)
     if (!todo->description().isEmpty()) {
         *ts << "    <p>" << breakString(cleanChars(todo->description())) << "</p>" << endl;
     }
-    if (relations.count()) {
+    if (!relations.isEmpty()) {
         *ts << "    <div align=\"right\"><a href=\"#sub" << todo->uid()
             << "\">" << i18nc("@title:column sub-to-dos of the parent to-do",
                               "Sub-To-dos") << "</a></div>" << endl;
@@ -759,7 +759,7 @@ void HtmlExportJob::formatCategories(QTextStream *ts, const KCalCore::Incidence:
 void HtmlExportJob::formatAttendees(QTextStream *ts, const KCalCore::Incidence::Ptr &incidence)
 {
     KCalCore::Attendee::List attendees = incidence->attendees();
-    if (attendees.count()) {
+    if (!attendees.isEmpty()) {
         *ts << "<em>";
         const KContacts::Addressee organizer = d->mOrganizersMap.value(incidence->uid());
         if (!organizer.isEmpty()) {
