@@ -86,6 +86,7 @@ public:
 
     QString iconForIncidence(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
     {
+        Q_UNUSED(incidence);
         return QString();
     }
 
@@ -105,7 +106,7 @@ Quickview::Quickview(const KPIM::Person &person, const Akonadi::Collection &col)
     , mCollection(col)
     , mDayRange(7)
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
@@ -140,10 +141,7 @@ Quickview::Quickview(const KPIM::Person &person, const Akonadi::Collection &col)
         //create etm for mCollection
         Akonadi::ChangeRecorder *monitor = new Akonadi::ChangeRecorder(this);
         Akonadi::ItemFetchScope scope;
-        QStringList allMimeTypes;
-
-        allMimeTypes << KCalCore::Event::eventMimeType() << KCalCore::Todo::todoMimeType()
-                     << KCalCore::Journal::journalMimeType();
+        const QStringList allMimeTypes = { KCalCore::Event::eventMimeType(), KCalCore::Todo::todoMimeType(), KCalCore::Journal::journalMimeType()};
 
         scope.fetchFullPayload(true);
         scope.fetchAttribute<Akonadi::EntityDisplayAttribute>();
@@ -153,7 +151,7 @@ Quickview::Quickview(const KPIM::Person &person, const Akonadi::Collection &col)
         monitor->setItemFetchScope(scope);
         monitor->setAllMonitored(true);
 
-        foreach (const QString &mimetype, allMimeTypes) {
+        for (const QString &mimetype : allMimeTypes) {
             monitor->setMimeTypeMonitored(mimetype, true);
         }
 
@@ -194,4 +192,3 @@ void Quickview::onTodayClicked()
     start = start.addDays(-QDate::currentDate().dayOfWeek() + 1);
     mAgendaView->showDates(start, start.addDays(mDayRange - 1));
 }
-
